# swagger-client
Nowcast weather data for latitude/longitude points, ZIP/Postal Codes, Designated Market Areas, and OnPoint™ points. The Weather Source Nowcast API is built upon the [OnPoint™ Platform](https://weathersource.com/products/onpoint-platform/) which ensures data that is gap-free, homogeneous, and ready for immediate analysis. We offer the highest resolution grid on the market, covering every landmass in the world and up to 200 miles offshore.  An API key is required to authorize requests. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). 

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 2.0.0
- Package version: 1.0.0
- Build package: io.swagger.codegen.v3.generators.python.PythonClientCodegen
For more information, please visit [https://developer.weathersourceapis.com/](https://developer.weathersourceapis.com/)

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import swagger_client 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import swagger_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint

# Configure API key authorization: ApiKeyAuth
configuration = swagger_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'

# create an instance of the API class
api_instance = swagger_client.DmasApi(swagger_client.ApiClient(configuration))
dma_id = 56 # int | A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
fields = ['fields_example'] # list[str] | A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(cldCvr)* * allHum *(relHum, spcHum)* * allPrecip *(precipFlag, precipIntensity, snowfallFlag, snowfallIntensity)* * allPres *(mslPres, presTend, sfcPres)* * allRad *(radSolar)* * allTemp *(dewPt, feelsLike, heatIndex, temp, wetBulb, windChill)* * allWind *(windDir, windDir80m, windDir100m, windSpd, windSpd80m, windSpd100m)* * popular *(cldCvr, feelsLike, precipFlag, precipIntensity, relHum, snowfallFlag, snowfallIntensity, temp, windDir, windSpd)* 
unit_scale = 'IMPERIAL' # str | The unit scale for returned values.<br> (optional) (default to IMPERIAL)

try:
    # A nowcast for a DMA.
    api_response = api_instance.dmas_dma_id_get(dma_id, fields, unit_scale=unit_scale)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling DmasApi->dmas_dma_id_get: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *https://nowcast.weathersourceapis.com/v2*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DmasApi* | [**dmas_dma_id_get**](docs/DmasApi.md#dmas_dma_id_get) | **GET** /dmas/{dmaId} | A nowcast for a DMA.
*OnpointsApi* | [**onpoints_onpoint_id_get**](docs/OnpointsApi.md#onpoints_onpoint_id_get) | **GET** /onpoints/{onpointId} | A nowcast for an OnPoint™ point.
*PointsApi* | [**points_latitudelongitude_get**](docs/PointsApi.md#points_latitudelongitude_get) | **GET** /points/{latitude},{longitude} | A nowcast for a Latitude/Longitude point.
*PostcodesApi* | [**postcodes_postcodecountry_code_get**](docs/PostcodesApi.md#postcodes_postcodecountry_code_get) | **GET** /postcodes/{postcode},{countryCode} | A nowcast for a postcode.

## Documentation For Models

 - [BoundingPoints](docs/BoundingPoints.md)
 - [BoundingPointsInner](docs/BoundingPointsInner.md)
 - [CldCvr](docs/CldCvr.md)
 - [CountryCode](docs/CountryCode.md)
 - [CountryName](docs/CountryName.md)
 - [DewPt](docs/DewPt.md)
 - [Distance](docs/Distance.md)
 - [DistancePop](docs/DistancePop.md)
 - [DmaId](docs/DmaId.md)
 - [DmaName](docs/DmaName.md)
 - [DmaObj](docs/DmaObj.md)
 - [ErrorObj](docs/ErrorObj.md)
 - [FeelsLike](docs/FeelsLike.md)
 - [FieldListObj](docs/FieldListObj.md)
 - [Fields](docs/Fields.md)
 - [Grid](docs/Grid.md)
 - [HeatIndex](docs/HeatIndex.md)
 - [Latitude](docs/Latitude.md)
 - [Longitude](docs/Longitude.md)
 - [MslPres](docs/MslPres.md)
 - [NowcastArr](docs/NowcastArr.md)
 - [NowcastDmaObj](docs/NowcastDmaObj.md)
 - [NowcastObj](docs/NowcastObj.md)
 - [NowcastOnpointObj](docs/NowcastOnpointObj.md)
 - [NowcastPointObj](docs/NowcastPointObj.md)
 - [NowcastPostcodeObj](docs/NowcastPostcodeObj.md)
 - [OnpointId](docs/OnpointId.md)
 - [OnpointObj](docs/OnpointObj.md)
 - [PointObj](docs/PointObj.md)
 - [Population](docs/Population.md)
 - [Postcode](docs/Postcode.md)
 - [PostcodeObj](docs/PostcodeObj.md)
 - [PrecipFlag](docs/PrecipFlag.md)
 - [PrecipIntensity](docs/PrecipIntensity.md)
 - [PresTend](docs/PresTend.md)
 - [RadSolar](docs/RadSolar.md)
 - [RelHum](docs/RelHum.md)
 - [SamplePoints](docs/SamplePoints.md)
 - [SamplePointsInner](docs/SamplePointsInner.md)
 - [SfcPres](docs/SfcPres.md)
 - [SnowfallFlag](docs/SnowfallFlag.md)
 - [SnowfallIntensity](docs/SnowfallIntensity.md)
 - [SpcHum](docs/SpcHum.md)
 - [SubdivCode](docs/SubdivCode.md)
 - [SubdivName](docs/SubdivName.md)
 - [Temp](docs/Temp.md)
 - [Timestamp](docs/Timestamp.md)
 - [Timezone](docs/Timezone.md)
 - [WetBulb](docs/WetBulb.md)
 - [WindChill](docs/WindChill.md)
 - [WindDir](docs/WindDir.md)
 - [WindDir100m](docs/WindDir100m.md)
 - [WindDir80m](docs/WindDir80m.md)
 - [WindSpd](docs/WindSpd.md)
 - [WindSpd100m](docs/WindSpd100m.md)
 - [WindSpd80m](docs/WindSpd80m.md)

## Documentation For Authorization


## ApiKeyAuth

- **Type**: API key
- **API key parameter name**: X-API-KEY
- **Location**: HTTP header


## Author

support@weathersource.com
